@@ -86,12 +86,13 @@ void DancingBars::configureSettings()
   SensorModelEntry::List list;
   for(int i = 0; i < mBars; i++){
     SensorModelEntry entry;
+    auto sensor = sensors().at( i );
     entry.setId( i );
-    entry.setHostName( sensors().at( i )->hostName() );
-    entry.setSensorName( KSGRD::SensorMgr->translateSensor( sensors().at( i )->name() ) );
+    entry.setHostName( sensor->hostName() );
+    entry.setSensorName( KSGRD::SensorMgr->translateSensor( sensor->name() ) );
     entry.setLabel( mPlotter->footers[ i ] );
-    entry.setUnit( KSGRD::SensorMgr->translateUnit( sensors().at( i )->unit() ) );
-    entry.setStatus( sensors().at( i )->isOk() ? i18n( "OK" ) : i18n( "Error" ) );
+    entry.setUnit( KSGRD::SensorMgr->translateUnit( sensor->unit() ) );
+    entry.setStatus( sensor->isOk() ? i18n( "OK" ) : i18n( "Error" ) );
 
     list.append( entry );
   }
@@ -114,12 +115,37 @@ void DancingBars::configureSettings()
   mPlotter->mBackgroundColor = dlg.backgroundColor();
   mPlotter->fontSize = dlg.fontSize();
 
+  // Each deleted Id is relative to the length of the list
+  // at the time of deletion.
   QList<uint> deletedIds = dlg.getDeletedIds();
-
   for(int i = 0; i<deletedIds.count(); i++){
 	  removeSensor(deletedIds[i]);
   }
 
+  // If the range has reset to "auto-range" then we need to ask for
+  // sensor info to re-calibrate. In answerReceived() there's a special-
+  // case recalibrating on sensor 0 (with id 100), so ask for that one.
+  if ( mPlotter->getMin() == 0.0 && mPlotter->getMax() == 0.0 && mBars > 0 ) {
+      const auto& sensor = sensors().at( 0 );
+      // The 100 is magic in answerReceived()
+      sendRequest( sensor->hostName(), sensor->name() + QLatin1Char('?'), 100 );
+  }
+
+  // The remaining entries in the dialog are the ones that haven't been
+  // deleted, so that should match the remaining sensors. The dialog does
+  // not edit units or real sensor information, but can change the label.
+  // Reset the footer labels as needed.
+  const auto remainingSensors = dlg.sensors();
+  if (remainingSensors.count() == mPlotter->footers.count())
+  {
+    for(int i = 0; i < remainingSensors.count(); ++i) {
+      const auto newLabel = remainingSensors.at(i).label();
+      if (newLabel != mPlotter->footers[ i ]) {
+        mPlotter->footers[ i ] = newLabel;
+      }
+    }
+  }
+
   repaint();
 }
 
