@@ -32,7 +32,7 @@
 #include <QStandardPaths>
 
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <ksignalplotter.h>
 
 #include <ksgrd/SensorManager.h>
@@ -42,6 +42,16 @@
 
 #include "FancyPlotter.h"
 
+// The unicode character 0x25CF is a big filled in circle.  We would prefer 
+// to use this in the tooltip (or other messages). However it's possible 
+// that the font used to draw the tooltip won't have it.  So we fall back to a 
+// "#" instead.
+static constexpr const int BLACK_CIRCLE = 0x25CF;
+static inline QChar circleCharacter(const QFontMetrics& fm)
+{
+    return fm.inFont(QChar(BLACK_CIRCLE)) ? QChar(BLACK_CIRCLE) : QLatin1Char('#');
+}
+
 class SensorToAdd {
   public:
     QRegExp name;
@@ -66,10 +76,7 @@ class FancyPlotterLabel : public QLabel {
         labelName = name;
 
         if(indicatorSymbol.isNull()) {
-            if(fontMetrics().inFont(QChar(0x25CF)))
-                indicatorSymbol = QChar(0x25CF);
-            else
-                indicatorSymbol = QLatin1Char('#');
+            indicatorSymbol = circleCharacter(fontMetrics());
         }
         changeLabel(color);
 
@@ -162,14 +169,7 @@ FancyPlotter::FancyPlotter( QWidget* parent,
     mNumAnswers = 0;
     mLabelsWidget = nullptr;
 
-    //The unicode character 0x25CF is a big filled in circle.  We would prefer to use this in the tooltip.
-    //However it's maybe possible that the font used to draw the tooltip won't have it.  So we fall back to a 
-    //"#" instead.
-    QFontMetrics fm(QToolTip::font());
-    if(fm.inFont(QChar(0x25CF)))
-        mIndicatorSymbol = QChar(0x25CF);
-    else
-        mIndicatorSymbol = QLatin1Char('#');
+    mIndicatorSymbol = circleCharacter(QFontMetrics(QToolTip::font()));
 
     QBoxLayout *layout = new QVBoxLayout(this);
     layout->setSpacing(0);
@@ -291,12 +291,17 @@ void FancyPlotter::configureSettings()
     connect(mSettingsDialog, &FancyPlotterSettings::okClicked, this, &FancyPlotter::applySettings);
     connect(mSettingsDialog, &FancyPlotterSettings::finished, this, &FancyPlotter::settingsFinished);
 
-    mSettingsDialog->open();	// open() opens the dialog modaly (ie. blocks the parent window)
+    mSettingsDialog->open();	// open() opens the dialog modally (ie. blocks the parent window)
 }
 
 void FancyPlotter::settingsFinished()
 {
-    applySettings();
+    if(mSettingsDialog->result() == QDialog::Accepted) {
+        // Apply and OK also connect to applySettings, but it's
+        // racy which slot is called first when OK is clicked:
+        // so do it here, too, and worst case we'll apply twice while OKing.
+        applySettings();
+    }
     mSettingsDialog->hide();
     mSettingsDialog->deleteLater();
     mSettingsDialog = nullptr;
@@ -494,6 +499,23 @@ bool FancyPlotter::removeBeam( uint beamId )
     return true;
 }
 
+static inline bool isPercentage(FPSensorProperties* sensor)
+{
+    return sensor->unit() == QLatin1String("%");
+}
+
+// The "useful precision" of a value; integers don't need
+// any decimal point, percentages can do with 0.1% or 99.9%,
+// and the rest should be fine with 2 digits.
+static inline int usefulPrecision(FPSensorProperties* sensor)
+{
+    if (sensor->isInteger)
+        return 0;
+    if (isPercentage(sensor))
+        return 1;
+    return 2;
+}
+
 void FancyPlotter::setTooltip()
 {
     QString tooltip = QStringLiteral("<qt><p style='white-space:pre'>");
@@ -513,8 +535,9 @@ void FancyPlotter::setTooltip()
             description = sensor->name();
 
         if(sensor->isOk()) {
-            lastValue = QLocale().toString( sensor->lastValue, (sensor->isInteger)?0:-1 );
-            if (sensor->unit() == QLatin1String("%"))
+            static_assert(std::is_same<double, decltype(sensor->lastValue)>::value, "Sensor values should be double");
+            lastValue = QLocale().toString( sensor->lastValue, 'f', usefulPrecision(sensor) );
+            if (isPercentage(sensor))
                 lastValue = i18nc("units", "%1%", lastValue);
             else if( !sensor->unit().isEmpty() )
                 lastValue = i18nc("units", QString(QLatin1String("%1 ") + sensor->unit()).toUtf8().constData(), lastValue);
@@ -583,16 +606,17 @@ void FancyPlotter::sendDataToPlotter( )
                         precision = (sensor->isInteger && mPlotter->scaleDownBy() == 1)?0:-1;
                         lastValue = mPlotter->lastValueAsString(beamId, precision);
                     } else {
-                        precision = (sensor->isInteger)?0:-1;
-                        lastValue = QLocale().toString( mPlotter->lastValue(beamId), precision );
-                        if (sensor->unit() == QLatin1String("%"))
+                        static_assert(std::is_same<double, decltype(mPlotter->lastValue(beamId))>::value, "Beam values should be double");
+                        precision = usefulPrecision(sensor);
+                        lastValue = QLocale().toString( mPlotter->lastValue(beamId), 'f', precision );
+                        if (isPercentage(sensor))
                             lastValue = i18nc("units", "%1%", lastValue);
                         else if( !sensor->unit().isEmpty() )  {
                             lastValue = i18nc("units", QString(QLatin1String("%1 ") + sensor->unit()).toUtf8().constData(), lastValue);
                         }
                     }
 
-                    if(sensor->maxValue != 0 && sensor->unit() != QLatin1String("%")) {
+                    if(sensor->maxValue != 0 && !isPercentage(sensor)) {
                         //Use a multi length string incase we do not have enough room
                         lastValue = i18n("%1 of %2", lastValue, mPlotter->valueAsString(sensor->maxValue, precision) ) + "\xc2\x9c" + lastValue;
                     }
