@@ -214,6 +214,7 @@ int updateDiskStat( void )
          */
         if ( (mnt_info->mnt_fsname[0] != '/') ||
              !strncmp( mnt_info->mnt_fsname, "/dev/loop", 9 ) ||
+             !strncmp( mnt_info->mnt_type, "fuse", 4 ) ||
              !strcmp( mnt_info->mnt_type, "smbfs" ) ||
              !strcmp( mnt_info->mnt_type, "cifs" ) ||
              !strcmp( mnt_info->mnt_type, "proc" ) ||
@@ -235,8 +236,12 @@ int updateDiskStat( void )
         strncpy( disk_info->device, mnt_info->mnt_fsname, sizeof( disk_info->device ) );
         disk_info->device[ sizeof(disk_info->device) -1] = 0;
 
-        strncpy( disk_info->mntpnt, mnt_info->mnt_dir, sizeof( disk_info->mntpnt ) );
-        disk_info->mntpnt[ sizeof(disk_info->mntpnt) - 1] = 0;
+        if ( strcmp(mnt_info->mnt_dir, "/") == 0 ) {
+            strncpy( disk_info->mntpnt, "/__root__", 9);
+        } else {
+            strncpy( disk_info->mntpnt, mnt_info->mnt_dir, sizeof( disk_info->mntpnt ) );
+            disk_info->mntpnt[ sizeof(disk_info->mntpnt) - 1] = 0;
+        }
         sanitize(disk_info->mntpnt);
 
         push_ctnr( DiskStatList, disk_info );
@@ -322,7 +327,13 @@ void printDiskStatUsedInfo( const char* cmd )
 {
     char *mntpnt = getMntPnt( cmd );
 
-    output( "%s Used\t0\t%ld\tKB\n", mntpnt, getTotal( mntpnt ) );
+    if ( strcmp( mntpnt, "/all" ) == 0 ) {
+        output( "All Partitions Used\t0\t%ld\tKB\n", getTotal( mntpnt ) );
+    } else if ( strcmp( mntpnt, "/__root__" ) == 0 ) {
+        output( "Filesystem Root Used\t0\t%ld\tKB\n", getTotal( mntpnt ) );
+    } else {
+        output( "%s Used\t0\t%ld\tKB\n", mntpnt, getTotal( mntpnt ) );
+    }
 }
 
 void printDiskStatFree( const char* cmd )
@@ -355,7 +366,13 @@ void printDiskStatFreeInfo( const char* cmd )
 {
     char *mntpnt = (char*)getMntPnt( cmd );
 
-    output( "%s Available\t0\t%ld\tKB\n", mntpnt, getTotal( mntpnt ) );
+    if ( strcmp( mntpnt, "/all" ) == 0 ) {
+        output( "All Partitions Available\t0\t%ld\tKB\n", getTotal( mntpnt ) );
+    } else if ( strcmp( mntpnt, "/__root__" ) == 0 ) {
+        output( "Filesystem Root Available\t0\t%ld\tKB\n", getTotal( mntpnt ) );
+    } else {
+        output( "%s Available\t0\t%ld\tKB\n", mntpnt, getTotal( mntpnt ) );
+    }
 }
 
 void printDiskStatPercent( const char* cmd )
@@ -393,7 +410,13 @@ void printDiskStatPercent( const char* cmd )
 void printDiskStatPercentInfo( const char* cmd )
 {
     char *mntpnt = (char*)getMntPnt( cmd );
-    output( "%s Percentage Used\t0\t100\t%%\n", mntpnt );
+    if ( strcmp( mntpnt, "/all" ) == 0 ) {
+        output( "All Partitions\t0\t100\t%%\n" );
+    } else if ( strcmp( mntpnt, "/__root__" ) == 0 ) {
+        output( "Filesystem Root\t0\t100\t%%\n" );
+    } else {
+        output( "%s\t0\t100\t%%\n", mntpnt );
+    }
 }
 
 void printDiskStatTotal( const char* cmd )
@@ -405,5 +428,11 @@ void printDiskStatTotal( const char* cmd )
 void printDiskStatTotalInfo( const char* cmd )
 {
     char *mntpnt = (char*)getMntPnt( cmd );
-    output( "%s Total Size\t0\t0\tKB\n", mntpnt);
+    if ( strcmp( mntpnt, "/all" ) == 0 ) {
+        output("All Partitions Total Size\t0\t0\tKB\n" );
+    } else if ( strcmp( mntpnt, "/__root__" ) == 0 ) {
+        output( "Filesystem Root Total Size\t0\t0\tKB\n" );
+    } else {
+        output( "%s Total Size\t0\t0\tKB\n", mntpnt );
+    }
 }
